#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.



# This file is a part of VHFFS4 Hosting Platform
# Please respect the licence of this file and the whole software

# Author: soda < dieu at gunnm dot org>

package Vhffs::Services::Svn;

use base qw(Vhffs::Object);
use Vhffs::Group;
use strict;
use DBI;



sub new
{
    my $main;
    my $reponame;
    my $this;
    my $self;
    my $class;
    my $user;
    my $group;
    
    $class = shift;
    $main = shift;
    $reponame = shift;
    $user = shift;
    $group = shift;
    
    $this = {};
    
    $this = $class->SUPER::new( $main , 1 , '401' );
    
    #We return an undefined value if the user or the SVNROOT are not correct
    return undef if( ! defined ( $reponame ) );
    return undef if( length( $reponame ) < 3 );
    return undef if( ! ( $reponame =~ /^[a-z0-9]+$/ ) );
    

    $this->{'user'} = $user;
    $this->{'group'} = $group;
    $this->{'reponame'} = $reponame;
    $this->{'public'} = 1;
    
    bless( $this , $class );
    
    return $this;
}

sub delete
{
    my $self = shift;
    my $query;
    my $request;

    $query = "DELETE FROM vhffs_svn WHERE object_id='".$self->{'object_id'}."'";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
    $request->execute or return -1;

    return -1 if( $self->SUPER::delete < 0 );
}



sub create
{
    my $self = shift;
    
   
    return -2 if ( !defined $self->{'user'} || $self->{'user'}->fetch < 0 );
    return -3 if ( !defined $self->{'group'} || $self->{'group'}->fetch < 0 );


    my $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_svn WHERE reponame='" . $self->{'reponame'} ."' AND owner_gid='".$self->{'group'}->get_gid."'");
    my $rows = $request->execute;
    return -1 if ( $rows != 0 );


    $self->{'owner_uid'} = $self->{'user'}->get_uid;
    
    my $oid = $self->SUPER::create();
    if ( $oid lt 0 )
    {
		return( -1 );
    }
    else
    {
		$self->{'object_id'} = $oid;
    }
    
    
    #Finally, create the object
    my $text = "INSERT INTO vhffs_svn (reponame,owner_uid,owner_gid,public,object_id) VALUES( '".$self->{'reponame'} . "','".$self->{'user'}->get_uid."','".$self->{'group'}->get_gid."' , '1' , '".$self->{'object_id'}."' )";
    $request = $self->{'db'}->{'DB_WRITE'}->prepare( $text );
    $request->execute or return -2;
    
    return 1;
}


sub fetch
{
    my $self = shift;
    

    my $query = "SELECT * FROM vhffs_svn where reponame='".$self->{'reponame'}."' AND owner_gid='".$self->{'group'}->get_gid."'";
    my $request = $self->{'db'}->{'DB_READ'}->prepare( $query )  or return -1;
    
    my $rows =  $request->execute() or return -3;

	return -2 if( $rows <= 0 );
    
    my $result = $request->fetchrow_hashref();
    
    
    foreach ( keys %{$result} )
    {
		$self->{$_} = $result->{$_}
    }
    
    
    $self->{'group'} = new Vhffs::Group( $self->{'main'} , undef ,  $self->{'owner_uid'} , $self->{'owner_gid'} );
    return -1 if( $self->{'group'}->fetch < 0 );
    
    $self->{'user'} = new  Vhffs::User( $self->{'main'} , undef , $self->{'owner_uid'} );
    return -1 if( $self->{'user'}->fetch < 0 );
    
    
    $self->SUPER::fetch;
    
    return 1;
}



sub get_users
{
	my $self = shift;
	
	return( $self->{'users'} );
}



sub commit
{
	my $self = shift;	

	my $query = "UPDATE vhffs_svn SET public= '".$self->{'public'}."' WHERE svn_id=$self->{'svn_id'}";
	my $request = $self->{'db'}->{'DB_WRITE'}->prepare($query);
	$request->execute;

	$self->SUPER::commit;
}


sub set_public
{
	my $self = shift;
	$self->{'public'} = 1;
}

sub set_private
{
	my $self = shift;
	$self->{'public'} = 0;
}

sub is_public
{
	my $self = shift;
	
	return -1 if( ! defined $self->{'public'} );

	if( $self->{'public'} == 1 )
	{
		return 1;
	}
	else
	{
		return 0;
	}
}

sub set_user
{
	my ( $self , $user ) = @_;
	$self->{'user'} = $user;
}

sub set_group
{
	my ( $self , $group ) = @_;
	$self->{'group'} = $group;
}

sub get_reponame
{
	my $self = shift;
	return $self->{'reponame'};
}


sub get_owneruid
{
	my( $self ) = @_;
	return $self->{'owner_uid'};
}

sub get_ownergid
{
	my $self = shift;
	return $self->{'owner_gid'};
}

sub get_title
{
	my $self = shift;
	return $self->{'reponame'};
}


sub getall
{
    my $vhffs = shift;
    my $state = shift;
    my $name = shift;
    my $group = shift;

    my $query;
    my $request;

    my $objs;
    my $result;
    my $tmp;
	
	
	$query = "SELECT * FROM  vhffs_svn s, vhffs_object o WHERE s.object_id = o.object_id ";
	$query.= " AND o.state='".$state."'" if( defined $state);
	$query.= " AND s.owner_gid='".$group->get_gid."'" if( defined $group);
	$query.= " AND s.reponame LIKE '%".$name."%'" if( defined $name);
    $query .= " ORDER BY reponame";

    $request = $vhffs->{'db'}->{'DB_READ'}->prepare( $query );
    
    my $rows = $request->execute;
    
    return undef if( $rows == 0);

    while( $result = $request->fetchrow_hashref )
    {
	my $group = new Vhffs::Group( $vhffs , undef , $result->{'owner_uid'} , $result->{'owner_gid'} );

        $tmp = new Vhffs::Services::Svn( $vhffs , $result->{'reponame'} , undef , $group );
        if( ( defined ( $tmp ) ) && ( $tmp->fetch > 0 ) )
        {
            push @{$objs} , $tmp;
        }
    }
    return $objs;
}


sub getall_by_group
{
    my $vhffs = shift;
    my $group = shift;

    my $query;
    my $request;

    my $objs;
    my $result;
    my $tmp;

    return undef if( $group->fetch < 1 );
     
    $query = "SELECT s.reponame, s.object_id FROM  vhffs_svn s, vhffs_object o WHERE s.object_id = o.object_id AND s.owner_gid='".$group->get_gid."'";
    
    $request = $vhffs->{'db'}->{'DB_READ'}->prepare( $query );
    my $rows = $request->execute;

    return undef if( $rows == 0);

    $result = $request->fetchall_hashref( 'reponame' );

    foreach( keys %{$result} )
    {
        $tmp = new Vhffs::Services::Svn( $vhffs , $_  , undef , $group);
        if( ( defined ( $tmp ) ) && ( $tmp->fetch > 0 ) )
        {
            push @{$objs} , $tmp;
        }
    }
    return $objs;
}


sub get_dir
{
    my $self = shift;
    return undef if( ! defined $self );
    
    return( $self->{'main'}->get_config->get_datadir . "/svn/svnroot/" . $self->get_group->get_groupname . "/" . $self->get_reponame );
}



1;
