#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.



package Vhffs::User;

#Vhffs::User written by sod` <dieu AT gunnm DOT org>

#Vhffs::User implements Unix authentification as an module of Vhffs.
#You can manage user with Unix.
#libnss-postgresql must be used with it to have an account on a machine with the database


use base qw(Vhffs::Object);
use strict;
use DBI;
use Vhffs::Group;
use Vhffs::Functions;



sub new
{
    my $main;
    my $uid;
    my $name;
    my $this;
    my $self;
    my $class;
    
    $class = shift;
    $main  = shift;
    $name  = shift;
    $uid   = shift;


    $this = {};
    
    if( ! defined( $name ) )
    {
	$name = get_name_by_uid( $main , $uid );
    }

    return undef if( ! defined $name );	
    return undef if( length( $name ) < 3 );
    return undef if( length( $name ) > 12 );
    return undef if( ! ( $name =~ /^[a-z0-9]+$/ ) );
    
    $this = $class->SUPER::new( $main , 1 , $uid );
    $this->{'username'} = $name;
    $this->{'uid'} = $uid if ( defined $uid );
    $this->{'group'} = new Vhffs::Group( $main , $name , $uid );   
    $this->{'admin'} = 0;
    
    bless( $this , $class );
}



sub exists
{
    my $self;
    my $request;

    $self = shift;

    $request = $self->{'db'}->{'DB_WRITE'}->prepare("SELECT * FROM vhffs_users WHERE username = $self->{'username'}" ) or return -1;
    
    return -2 if ( ! defined $request->execute() );
    
    return 1;
}



# get unix informations for a user : uid, gid, username, status, homedir, ...
sub fetch_unix
{
    my $request;
    my $result;
    my $query;
    my $gid;
    my $self;
    my %hash;
    my $rows;

    $self = shift;

    $query = "SELECT * FROM vhffs_users where uid='".$self->{'uid'}."'" if( defined $self->{'uid'} );
    $query = "SELECT * FROM vhffs_users where username='".$self->{'username'}."'" if( defined $self->{'username'} );
    
    
    $request = $self->{'db'}->{'DB_READ'}->prepare( $query ) or return -2;
    
    $rows = $request->execute() or return -2;

    if ( $rows > 0  )
    {
        $result = $request->fetchrow_hashref();
	
	
        foreach ( keys %{$result} )
        {
            $self->{"$_"} = $result->{$_}
        }
        return 1;	
    }
    else
    {
        return -1;
    }

}


# get a complete user
# it fetch informations in the vhffs_users table and vhffs_user_info
sub fetch
{
    my $self;
    my $request;
    my $result;
    my $ret;

    $self = shift;

    return $ret if( ( $ret = $self->fetch_unix() ) < 0 );

    $request = $self->{'db'}->{'DB_READ'}->prepare("SELECT * FROM vhffs_user_info where uid=$self->{'uid'}") or return -2;
    
    $request->execute() or return -2;

    $result = $request->fetchrow_hashref();


    foreach ( keys %{$result} )
    {
		$self->{$_} = $result->{$_}
    }

    $self->{'group'}->fetch;

	my $v;
	foreach $v qw(firtname lastname address zipcode city country)
	{
		$self->{$v} =~ s/[\\]*//g if( defined $self->{$v} );	
	}

	$self->SUPER::fetch;
    return 1;    
}


#add a user to a group
sub add_group
{
    my $self;
    my $group;
    my $request;

    $self = shift;
    $group  = shift;
    
    return -1 if ( $group->fetch < 0 ) ;

    $request = $self->{'db'}->{'DB_WRITE'}->prepare("INSERT INTO vhffs_user_group VALUES( $self->get_uid , $group->get_gid  )");

    $request->execute() or return -2;

    return 1;
}


#create a new user with username and password
sub create
{
    my $self;
    my $config;
    my $conf;
    my $group;
    my $resultuid;
    my $uid;
    my $gid;
    my $request;
    my $query;
    my $rows;
    my $badusers;
	my $homedir;

    ( $self ) = @_ ;
    
  
    $conf = $self->{'main'}->get_config->get_users;
    $badusers = $self->{'main'}->get_config->get_bad_username;

    if( defined $badusers )
    {

        foreach ( @{$badusers} )
        {
            return -10 if ( $_ eq $self->{"username"} );
        }
    }
    
 
 	$self->{'username'} =~ tr/A-Z/a-z/;


    #verify if a user already exists
    $request = $self->{'db'}->{'DB_WRITE'}->prepare("SELECT * FROM vhffs_users WHERE username='" . $self->{'username'} . "'");
    $rows = $request->execute;
    return -1 if ( $rows != 0 );

    #verify if a group with the name of the user already exists
    $request = $self->{'db'}->{'DB_WRITE'}->prepare("SELECT * FROM vhffs_groups WHERE groupname='" . $self->{'username'} . "'");
    $rows = $request->execute;
    return -1 if ( $rows != 0 );

    #compute the UID, set the minuid if not found 
    $uid = $conf->{'minuid'};
    $resultuid = $self->{'db'}->{'DB_READ'}->selectall_arrayref("SELECT MAX(uid) , MAX(gid) FROM vhffs_users");
    $uid = $resultuid->[0][0] if ( defined $resultuid->[0][0] );
    $uid++;

    $self->{'uid'} = $uid;
    $self->{'owner_uid'} = $uid;
    
	my $oid = $self->SUPER::create();
    return -1 if ( $oid lt 0 );
   
	$self->{'admin'} = 0 if ( ! defined $self->{'admin'} );
   
    # get UID and GID for the current user. If gid is not given in parameters, we take the max of gid and create a group with the username
    
	$homedir = Vhffs::Functions::hash_homename( $self->{'username'}  , $self->{'main'} );

    $request = $self->{'db'}->{'DB_WRITE'}->prepare("INSERT INTO vhffs_users VALUES('" . $self->{'uid'} ."' , '3' , '$self->{'username'}' , '".$conf->{'shell'}."' , '' , '$homedir' , '".$self->{'admin'}."' , '$oid')");

    $request->execute() or return -2;
    

    $request = $self->{'db'}->{'DB_WRITE'}->prepare( "INSERT INTO vhffs_user_info VALUES( '". $self->{'uid'} ."' , now() , NULL , NULL , NULL , NULL , NULL, NULL, NULL , NULL)" );
    $request->execute or return -2;

    
    
    #Now, create the GID
    $self->{'group'} = new Vhffs::Group( $self->{'main'} , $self->{'username'} , $self->{'uid'} );
    $gid = $self->{'group'}->create;
    return -1 if ( $gid < 0 );
	$self->{'group'}->set_status( Vhffs::Constants::ACTIVATED );
	$self->{'group'}->commit;
    $self->{'gid'} = $gid;


    $request = $self->{'db'}->{'DB_WRITE'}->prepare("UPDATE vhffs_users SET gid = '" . $self->{'gid'} . "' WHERE username='" . $self->{'username'}."'") or return -2;
    $request->execute or return -3;

	$self->commit;
    
	return $self->{'uid'};
}




#modify a user
#use as this : modify_user($db->{'DB_WRITE'} , username , field , value);
#Example : modify_user($db->{'DB_WRITE'} , "soda" , "shell" , "/bin/bash");
sub modify
{
    my $field;
    my $value;
    my $self;
    my $request;

    ( $self , $field , $value ) = @_;
    
    return -1 if( $field eq "uid" );
    return -2 if( $field eq "username" );


    # if the field is username, shell, passwd or homedir, we will modify the vhffs_users table
    # if not, we modify vhffs_user_info table
    if ( $field eq "passwd" )
    {    	
        $request = $self->{'db'}->{'DB_WRITE'}->prepare("UPDATE vhffs_users SET passwd=" + Vhffs::Main::password_encrypt $value + " WHERE uid='$self->{'uid'}'") or return -3;
	
    }
    elsif( $field =~ /shell|status|homedir/ )
    {
        $request = $self->{'db'}->{'DB_WRITE'}->prepare("UPDATE vhffs_users SET $field='$value' WHERE uid='$self->{'uid'}'") or return -3;
    }
    else
    {
        $request = $self->{'db'}->{'DB_WRITE'}->prepare("UPDATE vhffs_user_info SET $field='$value' WHERE uid='$self->{'uid'}'") or return -3;
    }
    
    $request->execute() or return -4;
}

sub commit
{
    my $self = shift;

    #Exec the super method !

    $self->{'shell'} = $self->{'main'}->get_config->get_users->{'shell'} if (! defined $self->{'shell'} );
    $self->{'status'} = 'I' if ( ! defined $self->{'status'} );
    $self->{'admin'} = 0 if ( ! defined $self->{'admin'} );
	return -1 if ( ( ! defined $self->{'passwd'} ) || ( $self->{'passwd'} eq "" ) );


    $self->{'firstname'} = $self->{'main'}->get_config->get_users->{'default_firstname'} if ( !defined $self->{'firstname'} );
    $self->{'lastname'} = $self->{'main'}->get_config->get_users->{'default_lastname'} if ( !defined $self->{'lastname'} );
    $self->{'address'} = $self->{'main'}->get_config->get_users->{'default_address'} if ( !defined $self->{'address'} );
    $self->{'zipcode'} = $self->{'main'}->get_config->get_users->{'default_zipcode'} if ( !defined $self->{'zipcode'} );
    $self->{'city'} = $self->{'main'}->get_config->get_users->{'default_city'} if ( !defined $self->{'city'} );
    $self->{'mail'} = $self->{'main'}->get_config->get_users->{'default_mail'} if ( !defined $self->{'mail'} );
    $self->{'gpg_key'} = " " if( ( ! defined $self->{'gpg_key'} ) || ( $self->{'gpg_key'} eq "" ) );
    $self->{'country'} = $self->{'main'}->get_config->get_users->{'default_country'} if ( !defined $self->{'country'} );
    
    my $v;
    foreach $v qw(firstname lastname address zipcode city country)
    {
	$self->{$v} = quotemeta ( $self->{$v} );
    }
    
    my $request_info = "UPDATE vhffs_user_info SET firstname='".$self->{'firstname'} ."', lastname='".$self->{'lastname'}."', address='".$self->{'address'}."', zipcode='".$self->{'zipcode'}."', country='".$self->{'country'}."', mail='".$self->{'mail'}."', city='".$self->{'city'}."', gpg_key='".$self->{'gpg_key'}."' WHERE uid='".$self->{'uid'}."'";
    
#	print $request_info;
    
    my $request_unix = "UPDATE vhffs_users SET shell='".$self->{'shell'}."', passwd='".$self->{'passwd'}."', admin=".$self->{'admin'}." WHERE uid=".$self->{'uid'};
    
    
    return -1 if( $self->SUPER::commit < 0 );
    
    my $result_unix = $self->{'db'}->{'DB_WRITE'}->prepare($request_unix) or return -1;
    $result_unix->execute or return -4;
    my $result_info = $self->{'db'}->{'DB_WRITE'}->prepare($request_info) or return -2;
    $result_info->execute or return -3;
    
    return 1;
}




#Delete a user in the database
sub delete
{
    my $request;
    my $self;

    $self = shift;

    return -1 if ($self->fetch < 0 ); 

    return -1 if ( ! defined $self->{'username'} );
    return -1 if ( ! defined $self->{'uid'} );
    return -2 if ( $self->{'group'}->delete < 0 );

	# delete mail user if mail_user is enabled
	if( $self->{'main'}->get_config->use_mailuser == 1 )
	{
		use Vhffs::Services::Mail;
		use Vhffs::Services::MailUser;
		my $mu = init Vhffs::Services::MailUser( $self->{'main'} , $self );

		if( defined $mu  &&  $mu >= 0 )
		{
			$mu->delbox;
			$mu->delforward;
		}
	}

    $request = $self->{'db'}->{'DB_WRITE'}->prepare("DELETE FROM vhffs_panel_user_prefs WHERE uid='".$self->{'uid'}."'");
    $request->execute() or return -2;

    $request = $self->{'db'}->{'DB_WRITE'}->prepare("DELETE FROM vhffs_users WHERE uid='".$self->{'uid'}."'");
    $request->execute() or return -1;

    $request = $self->{'db'}->{'DB_WRITE'}->prepare("DELETE FROM vhffs_user_group WHERE uid='".$self->{'uid'}."'");
    $request->execute() or return -2;

    
	$self->SUPER::delete;

    return 1;
}






sub uid_exists
{
    my ( $dbh , $uid ) = @_;
    my $request;

    return -1 if ( !defined $uid);

    $request = $dbh->prepare("SELECT * FROM vhffs_users WHERE uid= '$uid'");
    $request->execute;
    
    return -1 if ( $request->rows != 1 );
    
}


sub check_password
{
	use Crypt::PasswdMD5;

	my $self = shift;
	my $clearpass = shift;

	my $dbpass = $self->get_password;
	return 1 if( $dbpass eq unix_md5_crypt($clearpass, $dbpass) );
	return 0;		
}


sub send_mail_user
{
	use Vhffs::Functions;
	my ( $user, $subject, $content ) = @_;

	my $vhffs = $user->{'main'};

	my $from;
	$from = $vhffs->get_config->get_master_mail;
	$from = "vhffs\@nosrc.com" if( ! defined $from );

	Vhffs::Functions::send_mail( $from , $user->get_mail, $subject, $content, $vhffs);
}


sub generate_password
{
	use Vhffs::Functions;
	my $user = shift;

	my $password = generate_random_password Vhffs::Functions;
	$user->set_password( $password );
	$user->commit;

	return $password;
}


#
# Some accessors
################

sub get_username
{
    my $self;
    $self = shift;

    return $self->{'username'};
}



sub get_firstname
{
    my $self;
    $self = shift;

    return $self->{'firstname'};
}


sub get_lastname
{
    my $self;
    $self = shift;

    return $self->{'lastname'};
}


sub get_city
{
    my $self;
    $self = shift;

    return $self->{'city'};
}

sub get_country
{
     my $self;
     $self = shift;

     return $self->{'country'};
}

sub get_gpg
{
    my $self;
    $self = shift;

    return $self->{'gpg_key'};
}

sub get_zipcode
{
    my $self;
    $self = shift;

    return $self->{'zipcode'};
}



sub get_home
{
    use Vhffs::Functions;

    my $self;
    $self = shift;

    return $self->{'homedir'}
}


sub get_password
{
    my $self;
    $self = shift;

    return $self->{'passwd'}
}


sub get_uid
{
    my $self = shift;

    if( defined $self->{'uid'} )
    {
        return $self->{'uid'};
    }
    else
    {
        return -1;
    }
}



sub get_gid
{
    my $self = shift;

    if( defined $self->{'gid'} )
    {
        return $self->{'gid'};
    }
    else
    {
        return -1;
    }
}

sub get_lang
{
    my $self = shift;

    my $query = "SELECT language FROM vhffs_panel_user_prefs WHERE uid='".$self->get_uid."'";
    my $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
    my $rows = $request->execute;
 
   if( $rows == 0 )
   {
     return Vhffs::Constants::DEFAULT_LANG;
   }
   else
   {
     my $value = $request->fetchrow_arrayref;
     return $value->[0];
   }
}



sub get_mail
{
	my $self = shift;
	return $self->{'mail'};
}

sub get_address
{
	my $self = shift;
	return $self->{'address'};
}

sub get_group
{
    my $self = shift;
    return $self->{'group'};
}

sub get_shell
{
    my $self = shift;
    return $self->{'shell'};
}


sub set_shell
{
    my $self = shift;
    my $value = shift;
    $self->{'shell'} = quotemeta $value;
}


sub set_firstname
{
    my $self = shift;
    my $value = shift;
    $self->{'firstname'} = quotemeta $value;
}

sub set_lastname
{
    my $self = shift;
    my $value = shift;
    $self->{'lastname'} = quotemeta $value;
}

sub set_city
{
    my $self = shift;
    my $value = shift;
    $self->{'city'} = quotemeta $value;
}


sub set_zipcode
{
    my $self = shift;
    my $value = shift;
    
    $self->{'zipcode'} = $value if( $value =~ /^[\d]+$/ );
}

sub set_country
{
    my $self = shift;
    my $value = shift;
    $self->{'country'} = quotemeta $value;
}

sub set_address
{
    my $self = shift;
    my $value = shift;
    $self->{'address'} = quotemeta $value;
}

sub set_mail
{
	use Vhffs::Functions;
   	my $self  = shift;
	my $value = shift;
   
	if(  Vhffs::Functions::valid_mail( $value ) == 1  )
	{
		$self->{'mail'} = $value;
	}
	else
	{
		return -1;
	}
}


sub get_gpgkey
{
    my $self  = shift;
    return( $self->{'gpg_key'} );
}



sub set_gpgkey
{
    my $self = shift;
    my $value = shift;
    $self->{'gpg_key'} = $value;
}

sub set_password
{
    use Vhffs::Functions;
    
    my $self = shift;
    my $value = shift;
    $self->{'passwd'} = Vhffs::Functions::password_encrypt( $value );
}

sub set_admin
{
    my ( $self , $value ) = @_;
	$self->{'admin'} = $value;
}

sub is_admin
{
	my $self = shift;
	if( ( defined $self->{'admin'} ) && ( $self->{'admin'} == Vhffs::Constants::USER_ADMIN  ) )
	{
		return 1;
	}
	else
	{
		return 0;
	}
}


sub is_moderator
{
	my $self = shift;
	if( ( defined $self->{'admin'} ) && ( $self->{'admin'} == Vhffs::Constants::USER_MODERATOR  ) )
	{
		return 1;
	}
	else
	{
		return 0;
	}
}



sub get_name_by_uid
{   
    my $main = shift;
    my $gid = shift;
    my $request = $main->{'db'}->{'DB_READ'}->prepare("SELECT username FROM vhffs_users where uid='".$gid."'") or return -2;
    my $rows = $request->execute();
    
    if( $rows == 0 )
    { 
        return( "nobody" );
    }
    else
    {
        my $result = $request->fetchrow_hashref();
        return( $result->{username} );
    }

}

sub getall
{
	my $vhffs = shift;
	my $state = shift ;
	my $name = shift ;
	my @users;
	return if( ! defined $vhffs );

	my $query;
	$query = "SELECT username FROM vhffs_users vu , vhffs_user_info vi, vhffs_object o  WHERE vu.uid=vi.uid AND o.object_id=vu.object_id ";
	$query.= " AND ( vu.username LIKE '%".$name."%' OR vi.firstname LIKE '%".$name."%' OR vi.lastname LIKE '%".$name."%' )" if( defined $name );
	$query.= " AND o.state='".$state."'" if( defined $state );
	$query.="ORDER BY username";
	
	
	my $request = $vhffs->{'db'}->{'DB_READ'}->prepare( $query );
	$request->execute;
	while( my $row = $request->fetchrow_arrayref )
	{   
	    my $user = new Vhffs::User( $vhffs , $row->[0]   , '401' );
	    if( ( defined $user ) && ( $user->fetch > 0 ) )
	    {   
		push @users , $user;
	    }
	}
	return \@users;
	
}


sub get_last_users
{
    my $vhffs = shift;
    my @users;

    return if ( !defined $vhffs );

    my $query = "SELECT username FROM vhffs_users ORDER BY uid DESC LIMIT 10";
    my $request = $vhffs->{'db'}->{'DB_READ'}->prepare( $query );
	$request->execute;
    while( my $row = $request->fetchrow_arrayref )
    {   
        my $user = new Vhffs::User( $vhffs , $row->[0]   , '401' );
        if( $user->fetch > 0 )
        {   
            push @users , $user;
        }
    }
    return \@users;

}


sub get_groups
{
	my $self = shift;

	return undef if( $self->fetch < 0 );
	my @groups;
	my $uid = $self->get_uid;
	my $query = "SELECT g.groupname FROM vhffs_groups g, vhffs_user_group ug WHERE ug.uid='".$uid."' AND g.gid=ug.gid ORDER BY g.groupname";
	my $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
	return undef if( $request->execute <= 0 );
	while( my $row = $request->fetchrow_arrayref )
	{
		my $group = new Vhffs::Group( $self->{'main'} , $row->[0] , '401' );
		push( @groups , $group ) if( $group->fetch );
	}
	return \@groups;
}


sub have_activegroups
{
	my $self = shift;

	return -1 if( $self->fetch < 0 );
	my $uid = $self->get_uid;

	my $query = "SELECT COUNT(g.groupname) FROM vhffs_groups g, vhffs_user_group ug, vhffs_object o WHERE ug.uid='".$uid."' AND g.gid=ug.gid AND o.object_id=g.object_id AND o.state='".Vhffs::Constants::ACTIVATED."'";
	my $request = $self->{'db'}->{'DB_READ'}->prepare( $query );
	return -1 if( $request->execute <= 0 );

	my $row = $request->fetchrow_arrayref;
	return -1 if ( ! defined $row );
	return $row->[0];
}

1;

__END__

=head1 NAME

Vhffs::User - Vhffs Interface to handle *NIX users

=head1 SYNOPSIS

	use Vhffs::Main;
	$vhffs = init Vhffs::Main;
	$user = new Vhffs::User( $vhffs , "myuser" , 401 );
	if( $user->fetch > 0 )
	{
		print "User exists\n";
	}
	else
	{
		print "User does not exists\n";
	}
	...
	if( $user->create > 0 )
	{
		print "User created";
	}
	else
	{
		print "User error\n";
	}
	...
	print "Username: $user->get_username";
	...
	if( $user->commit > 0 )
	{
		print "Update user status : succesfull\n";
	}

=head1 METHODS

For each method, returns 1 if success, 0 otherwise. If the method should returns a reference, returns undef if fails.

new( Vhffs::Main , "username" , "uid" ) : instanciate a new user

exists( ) : return 1 if the user exists, 0 otherwise

fetch( ) : fetch informations for this user from the database. You have to call fetch before working on the user

get_all_unix_users( ) - static method : returns a hashref with all unix users. Hashkey is the username

get_all_users( ) - static method : returns a hashref with all users. Hashkey is the username

add_group( Vhffs::Group ) : add a user in a group. Returns 1 if success, 0 otherwise

create( ) : create the user. Returns 1 if success, 0 otherwise

commit( ) : commit changes on the current instance on the database

delete( ) : delete the user from the platform

send_mail( $subject , $content ) : send a mail to the user. The subject of the mail is the first argument, the second if the content of the mail

generate_password( ) : generate a new password for this user. Returns the password.

get_username( )

get_firstname( )

get_lastname( )

get_city( )

get_country( )

get_gpg( )

get_zipcode( )

get_home( )

get_password( ) : returns the encrypted password

set_password( $clear ) : set a new password. New password is given in the argument

get_uid( )

get_gid( )

get_lang( )

get_mail( )

get_group( )

get_address( )

get_shell( )

set_username( $name )

set_firstname( $firstname )

set_lastname( $lastname )

set_city( $city )

set_country( $country )

set_gpg( $gpg )

set_zipcode( $zc )

set_admin( 1 or 0 )

set_mail( $mail )

set_address( )

set_shell( )

is_admin( ) : returns 1 if the user is admin 0 otherwise

is_moderator( ) : returns 1 if the user is moderator 0 otherwise

get_name_by_uid( $uid ) : returns the name that correspond to the uid given in parameter. Return "nobody" if no user own this uid

getall( Vhffs::Main , $state , $name )

get_last_users( ) : returns an array with the last 10 users

get_groups( ) : returns a arrayred with the groups of the user

have_groups( ) : returns 0 if user don't have groups, else returns the number of groups, returns < 0 if an error occured






=head1 SEE ALSO

Vhffs::Group , Vhffs::Main , Vhffs::Constants

=head1 AUTHOR

Julien Delange <julien at tuxfamily dot org>
