#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.



use POSIX;
use strict;
use locale;
use Locale::gettext;
use HTML::Template;
use CGI;
use CGI::Session;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Functions;
use Vhffs::Services::Mailing;
use Vhffs::Listengine::Listengine;
use Vhffs::Listengine::Intl;
use Vhffs::Listengine::Panel;


sub recursive_msg
{
	my $templatedir = shift;
	my $key = shift;
	my $msgs = shift;
	my $list = shift;
	my $retour;
	my $subtemplate;
	my $message;
	my $v;
	foreach $v ( keys %{$$msgs} )
	{
	    $message = $$msgs->{$v};
		if( ( $message->{'treated'} == 0 ) && ( $message->{'mid'} eq $key ) )
		{
		    $subtemplate = new HTML::Template( filename => $templatedir."/list_sub.tmpl");
		    $subtemplate->param( LISTNAME => "toto" );
		    $subtemplate->param( TEXT_VIEW => gettext("View") );
		    $subtemplate->param( MSG_ID => $v );
		
		    $subtemplate->param( MSG_SUBJECT => $message->{'mid'} . $message->get('Subject'));
		    $subtemplate->param( MSG_FROM => $message->get('From'));
		    $subtemplate->param( ANSWERS => recursive_msg( $templatedir , $key , $msgs ));
		    $retour .= $subtemplate->output;
			$message->{'treated'} = 1;
			$$msgs->{$v} = $message;
		}
	}
	return( $retour );
}


my $template;
my $mail;
my $vhffs = init Vhffs::Main;
my $archives;
my $subtemplate;


my $cgi = new CGI;


#On recupere les parametres
my $listname = $cgi->param("list");
my $day = $cgi->param("day");
my $month = $cgi->param("month");
my $year = $cgi->param("year");
my $method = $cgi->param("method");
my $changetheme = $cgi->param("changetheme");
my $changelang = $cgi->param("changelang");

my $cooklang = Vhffs::Listengine::Panel::cook_lang( $vhffs );


#On obtient le domaine, le local part et on construit l'objet de la liste
my( $lpart , $domain ) = split/\@/,$listname,2;
my $list = new Vhffs::Services::Mailing( $vhffs , $lpart , $domain );
my $templatedir = $vhffs->get_config->get_listengine_templatesdir;



$template = new HTML::Template( filename => $templatedir."/error.tmpl");


sub create_prefs_div
{
    my $template = shift;
    $template->param( TEXT_SUBMIT_THEME => gettext( "Change theme" ) );
    $template->param( TEXT_SUBMIT_LANG => gettext( "Change language" ) );
    
    $template->param( PREFS_THEME => Vhffs::Listengine::Panel::create_themes_select( $vhffs ) );
    $template->param( PREFS_LANG => Vhffs::Listengine::Panel::create_lang_select( $vhffs ) );
}


my $theme = Vhffs::Listengine::Panel::check_theme( $cgi->cookie("theme") );

if( Vhffs::Functions::valid_mail( $listname ) != 1 )
{
    $template = new HTML::Template( filename => $templatedir."/error.tmpl");
    $template->param( ERROR => sprintf( gettext("Bad listname %s"), $listname) );
}
elsif( ( ! defined $lpart ) || ( ! defined $domain ) )
{
    $template = new HTML::Template( filename => $templatedir."/error.tmpl");
    $template->param( ERROR => gettext("Error in listname") );
}
elsif( ( ! defined $list ) || ( $list->fetch < 0 ) )
{
    $template = new HTML::Template( filename => $templatedir."/error.tmpl");
    $template->param( ERROR => gettext("Undefined list") );

}
elsif( $list->get_open_archive != 1 )
{
    $template = new HTML::Template( filename => $templatedir."/error.tmpl");
    $template->param( ERROR => gettext("Archive are not open for this list") );

}
else
{
    my $retour;
    if( $method eq 'list' )
    {
	$template = new HTML::Template( filename => $templatedir."/list.tmpl");
	$template->param( VALUE_LISTNAME => $list->get_listname );
	$template->param( VALUE_YEAR => $year);
	$template->param( VALUE_MONTH => $month);
	$template->param( VALUE_DAY => $day);
	$template->param( TITLE_ARCHIVES => gettext("Archives") );
	$template->param( TEXT_BY_DAY => gettext("Back to list by day") );
	create_prefs_div( $template );
$template->param( THEME_NAME => $theme );

	my $msgs = Vhffs::Listengine::Listengine::get_messages_in_a_day( $list , $year , $month , $day );
	my $message;
	my $key;	
	foreach $key ( keys %{$$msgs} )
	{
	    $message = ${$msgs}->{$key};
		if( $message->{'treated'} == 0 )
		{
		    $subtemplate = new HTML::Template( filename => $templatedir."/list_sub.tmpl");
		    $subtemplate->param( LISTNAME => $list->get_listname );
		    $subtemplate->param( TEXT_VIEW => gettext("View") );
		    $subtemplate->param( MSG_ID => $key );
		
		    $subtemplate->param( MSG_SUBJECT => $message->get('Subject'));
		    $subtemplate->param( MSG_FROM => $message->get('From'));
#		    $subtemplate->param( ANSWERS => recursive_msg( $templatedir , $message->{'mid'} , $msgs , $list ));
		    $retour .= $subtemplate->output;
			$message->{'treated'} = 1;
			$$msgs->{$key} = $message;
		}
	}
	$template->param( MAIN => $retour );
    }
    elsif( $method eq 'byday' )
    {
	$template = new HTML::Template( filename => $templatedir."/byday.tmpl");
	$template->param( TEXT_BY_MONTH => sprintf( gettext("Back to archives by month ( %s )") , Vhffs::Listengine::Intl::value_month( $month ) ) );	
	$template->param( VALUE_LISTNAME => $list->get_listname );
	$template->param( VALUE_YEAR => $year);
	$template->param( TEXT_MONTH => Vhffs::Listengine::Intl::value_month( $month ) );
	create_prefs_div( $template );
$template->param( THEME_NAME => $theme );
	$template->param( TITLE_ARCHIVES => gettext("Archives") );

	my $days = Vhffs::Listengine::Listengine::get_days( $list , $year , $month );
	my $day;
	
	foreach ( @{$days} )
	{
	    $subtemplate = new HTML::Template( filename => $templatedir."/byday_sub.tmpl");
	    $subtemplate->param( LISTNAME => $list->get_listname );
	    $subtemplate->param( YEAR => $year );
	    $subtemplate->param( VALUE_YEAR => $year);
	    $subtemplate->param( VALUE_MONTH => $month);
	    $subtemplate->param( DAY => $_ );
	    $subtemplate->param( MONTH => $month );
	    $retour .= $subtemplate->output;
	}
	$template->param( MAIN => $retour );	
    }
    elsif( $method eq 'bymonth' )
    {
	$template = new HTML::Template( filename => $templatedir."/bymonth.tmpl");
	$template->param( VALUE_LISTNAME => $list->get_listname );
	$template->param( TITLE_ARCHIVES => gettext("Archives") );	
	$template->param( TEXT_BY_YEAR => sprintf( gettext("Back to archives by year ( %s )") , $year ) );
	create_prefs_div( $template );
$template->param( THEME_NAME => $theme );
	my $months = Vhffs::Listengine::Listengine::get_months( $list , $year );
	my $month;
	
	foreach ( @{$months} )
	{
	    $subtemplate = new HTML::Template( filename => $templatedir."/bymonth_sub.tmpl");
	    $subtemplate->param( LISTNAME => $list->get_listname );
	    $subtemplate->param( YEAR => $year );
	    $subtemplate->param( TEXT_ARCHIVES_MONTH => gettext("Archives for ") );
	    $subtemplate->param( MONTH => $_ );
	    $subtemplate->param( TEXT_MONTH => Vhffs::Listengine::Intl::value_month( $_ )  );
	    $retour .= $subtemplate->output;
	}
	$template->param( MAIN => $retour );	
    }
    else
    {
	$template = new HTML::Template( filename => $templatedir."/byyear.tmpl");
	$subtemplate = new HTML::Template( filename => $templatedir."/byyear_sub.tmpl");
	$template->param( VALUE_LISTNAME => $list->get_listname );
	$template->param( TITLE_ARCHIVES => gettext("Archives") );
	$template->param( THEME_NAME => $theme );

	create_prefs_div( $template );
	
	my $years = Vhffs::Listengine::Listengine::get_years( $list );
	my $year;
	
	foreach ( @{$years} )
	{
	    $subtemplate = new HTML::Template( filename => $templatedir."/byyear_sub.tmpl");
	    $subtemplate->param( LISTNAME => $list->get_listname );
	    $subtemplate->param( TEXT_ARCHIVES_YEAR => gettext("Archives for year") );
	    $subtemplate->param( YEAR => $_ );
	    $retour .= $subtemplate->output;
	}
	$template->param( MAIN => $retour );
    }

}


if( $cooklang )
{
	print CGI::header( -cookie=>$cooklang,
						-type => "text/html",
						-charset	=> "utf-8"
						);
	print $template->output;
}
else
{
	print "Content-Type: text/html; charset=utf-8\n\n".$template->output;
}
