#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Services::LargeFile;

my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $group = $panel->{'group'};
my $projectname = $session->param("project");
my $cgi = $panel->{'cgi'};
my $cgigroupname = $cgi->param('cgigroup');
my $filename = $cgi->param("name");
my $template;
my $output;
my $subtemplate;
my $file;
my $message;

if( defined $cgigroupname )
{
	$group = new Vhffs::Group( $vhffs , $cgigroupname , '401' );
	$group->fetch;
}

$file = new Vhffs::Services::LargeFile( $vhffs , $filename  , undef , $group );


if( ( ! defined $filename ) || ( ! defined $file ) )
{
	$template = open_template( $vhffs , "misc" , "simplemsg" );
	$message = gettext( "CGI Error" );
	$template->param( MESSAGE => $message );
}
elsif( ( ! defined $group ) || ( $group->fetch < 0 ) )
{
	$template = open_template( $vhffs , "misc" , "simplemsg" );
	$template->param( MESSAGE => gettext("Grant an user access to this repository") );
}
elsif( $file->fetch < 0 )
{
	$template = open_template( $vhffs , "misc" , "simplemsg" );
	$message = gettext( "Cannot get informations on this object");
	$template->param( MESSAGE => $message );

}
elsif( ( Vhffs::Acl::what_perm_for_user( $user , $file , $vhffs ) < Vhffs::Constants::ACL_VIEW ) && ( $user->is_admin != 1 ) )
{
	$template = open_template( $vhffs , "misc" , "simplemsg" );
	$message = gettext( "You're not allowed to do this (ACL rights)");
	$template->param( MESSAGE => $message );
}
elsif( ( $file->get_status != Vhffs::Constants::CREATED ) && ( $user->is_admin != 1 ) )
{
	$template = open_template( $vhffs , "misc" , "simplemsg" );
    $message = gettext( "This object is not functionnal yet. Please wait creation, moderation or modification.");
	$template->param( MESSAGE => $message );
}
else
{
	$template = open_template( $vhffs , "misc" , "simplemsg" );

	$file->set_status( Vhffs::Constants::WAITING_FOR_MODIFICATION );
	if( $file->commit != 1 )
	{
		$message = gettext( "Error when try to send informations" );
	}
	else
	{
		$message = gettext( "Please wait, your file will be moved in our public servers" );
	}
	$template->param( MESSAGE => $message );
}

display($panel, $template->output );
