#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Services::Mail;
use Vhffs::Acl;
use Vhffs::Constants;
my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $group = $panel->{'group'};
my $projectname = $session->param("project");
my $cgi = $panel->{'cgi'};
my $domain = $cgi->param("name");
my $template;
my $subtemplate;
my $subtemplate2;
my $message;
my $temp;

my $templatedir = $vhffs->get_config->get_templatedir;

my $mail = new Vhffs::Services::Mail( $vhffs , $domain , $user , $group );

if( $mail->fetch < 0 )
{

	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	my $message = gettext( "Cannot get informations on this object");
	$template->param( MESSAGE => $message );

}
elsif( ( $mail->get_status != Vhffs::Constants::ACTIVATED ) && ( $user->is_admin != 1 ) )
{
	
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	my $message = gettext( "This object is not functionnal yet. Please wait creation or moderation.");
	$template->param( MESSAGE => $message );
}
elsif( ( Vhffs::Acl::what_perm_for_user( $user , $mail , $vhffs ) < Vhffs::Constants::ACL_VIEW ) && ( $user->is_admin != 1 ) )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	my $message = gettext("You're not allowed to do this (ACL rights)");
	$template->param( MESSAGE => $message );
}
else
{
	$template = new HTML::Template( filename => $templatedir."/mail/prefs.tmpl" );

	$template->param( TEXT_TITLE => gettext("Mail Administration for domain ") );
	$template->param( VALUE_DOMAIN => $mail->get_domain );
	
	$template->param( SUBTITLE_CATCHALL => gettext("Catchall address") );
	$template->param( VALUE_CATCHALL => $mail->get_catchall );
	$template->param( TEXT_CATCHALL_EXPLAIN => gettext("Enter a mail address to catch all email for this domain") );
	$template->param( TEXT_CATCHALL => gettext("Catchall mail") );

	$template->param( SUBTITLE_ACCOUNTS => gettext("Accounts") );
	$template->param( TEXT_ACCOUNTS_LIST => gettext("List all accounts") );
	$template->param( TEXT_ACCOUNTS_ADD => gettext("Add an account") );
	
	$template->param( TEXT_ACCOUNT_LOCALPART => gettext("Local Part for this account") );
	$template->param( TEXT_ACCOUNT_PASSWORD => gettext("Password") );


	
	$template->param( SUBTITLE_FORWARDS => gettext("Forwards") );
	$template->param( TEXT_FORWARD_LIST => gettext("List all forwardings for this domain") );
	$template->param( TEXT_FORWARD_ADD => gettext("Add a forward on this domain") );
	
	$template->param( TEXT_FORWARD_FORM_LOCALPART => gettext("Local Part") );
	$template->param( TEXT_FORWARD_FORM_FORWARD => gettext("Forward mail") );



#	$template->param( TEXT_SEND => gettext("Modify") );
	$template->param( TEXT_CHANGE_CATCHALL => gettext("Change catchall forward") );
	$template->param( TEXT_ADD_ACCOUNT => gettext("Add a popbox to this domain") );
	$template->param( TEXT_ADD_FORWARD => gettext("Add a forward on this domain") );


	$template->param( TEXT_DELETE_MAIL => gettext("Delete this mail domain") );
	$template->param( TEXT_BEFORE_DELETE => gettext("This action is non-reversible. All services associated to this project will be DESTROYED.") );
	$template->param( ASK_DELETE_WEB => gettext("Are you SURE you want DELETE this Mail Area ?") );
	$template->param( YES => gettext("Yes I'm sure of what I do") );
	$template->param( NO => gettext("No, I'm not sure, I prefer to keep this project.") );
	$template->param( TEXT_DELETE => gettext("Delete") );

    $template->param( TEXT_ACL_ADMIN => gettext("Admin Rights on this object (ACL)") );
    $template->param( EXPLAIN_ADMIN_ACL => gettext("You can Manage rights on this service for each user in the VHFFS database. Please read help before manage it.") );
    $template->param( ADMIN_ACL => gettext( "Ok, go to ACL admin" ) );



	my $output = "";
	my $boxes = $mail->get_boxes;
	foreach( sort keys %{$boxes} )
	{
		$temp = "";
		$subtemplate = new HTML::Template( filename => $templatedir."/mail/prefs_box.tmpl" );
		$subtemplate->param( ACCOUNT => $_ . "\@" . $mail->get_domain );
		$subtemplate->param( LOCALPART => $_ );
		$subtemplate->param( TEXT_CHANGE_PASSWORD => gettext( "Change Password" ) );
		$subtemplate->param( TEXT_DELETE => gettext( "Delete this mail account" ) );
		$subtemplate->param( DOMAIN => $mail->get_domain );




		if( $vhffs->get_config->use_nospam == 1 )
		{
			$subtemplate2 = new HTML::Template( filename => $templatedir."/mail/prefs_spam.tmpl" );
			$subtemplate2->param( LOCALPART => $_ );
			$subtemplate2->param( DOMAIN => $mail->get_domain );
			if( $mail->use_nospam( $_ ) == 1 )
			{
				$message = gettext( "Disable anti-spam" );	
			}
			else
			{
				$message = gettext( "Enable anti-spam" );	
			}
			$subtemplate2->param( TEXT_SPAM => $message );
			$temp .= $subtemplate2->output;
		}



		if( $vhffs->get_config->use_novirus == 1 )
		{
			$subtemplate2 = new HTML::Template( filename => $templatedir."/mail/prefs_virus.tmpl" );
			$subtemplate2->param( LOCALPART => $_ );
			$subtemplate2->param( DOMAIN => $mail->get_domain );
			if( $boxes->{$_}{'novirus'} == 1 )
			{
					$message = gettext( "Disable anti-virus" );	
			}
			else
			{
				$message = gettext( "Enable anti-virus" );	
			}
			$subtemplate2->param( TEXT_VIRUS => $message );
			$temp .= $subtemplate2->output;
		}



		$subtemplate->param( OTHER => $temp );

		$output .= $subtemplate->output;
	}	
    $template->param( VALUE_ACCOUNTS => $output );

	$output = "";
	my $forwards = $mail->get_forwards;
	foreach( sort keys %{$forwards} )
	{
		$subtemplate = new HTML::Template( filename => $templatedir."/mail/prefs_forward.tmpl" );
		$subtemplate->param( LOCAL_PART => $_ . "\@" . $mail->get_domain );
		$subtemplate->param( FORWARD_MAIL => $forwards->{$_}{'remote_name'} );
		$subtemplate->param( LOCALPART => $_ );
		$subtemplate->param( TEXT_MODIFY_FORWARD => gettext( "Change Forward" ) );
		$subtemplate->param( TEXT_DELETE => gettext( "Delete this forward" ) );
		$subtemplate->param( DOMAIN => $mail->get_domain );
		$output .= $subtemplate->output;	
	}	
    $template->param( VALUE_FORWARD => $output );



}

display Vhffs::Panel::Main($panel, $template->output);
